#
# spec file for package nginx-module-njs
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nginx-module-njs
Version:        0.8.5
Release:        1.9
Summary:        NGINX module for NGINX Javascript
License:        BSD-2-Clause
Group:          Productivity/Networking/Web/Proxy
URL:            https://nginx.org/en/docs/njs/
Source:         nginx-module-njs-%{version}.tar.gz
BuildRequires:  nginx-source
%{ngx_conditionals}
%{ngx_requires}

%description
njs is a subset of the JavaScript language that allows extending
nginx functionality.

%prep
%autosetup -p1
cp -r %{_prefix}/src/nginx .

%build
cd nginx
%{ngx_configure} --add-dynamic-module=.
%make_build modules

%install
mkdir -p %{buildroot}/%{ngx_module_dir}
install -Dpm0755 nginx/objs/ngx_http_js_module.so %{buildroot}/%{ngx_module_dir}
install -Dpm0755 nginx/objs/ngx_stream_js_module.so %{buildroot}/%{ngx_module_dir}

%files
%license LICENSE
%doc CHANGES
%{ngx_module_dir}/ngx_http_js_module.so
%{ngx_module_dir}/ngx_stream_js_module.so

%changelog
* Mon Jul 22 2024 Adam Majer <adam.majer@suse.de>
- update to 0.8.5:
  nginx modules:
  * Change: r.variables.var, r.requestText, r.responseText,
    s.variables.var, and the data argument of the s.on() callback with
    upload or download event types will now convert bytes invalid in
    UTF-8 encoding into the replacement character. When working with
    binary data, use r.rawVariables.var, r.requestBuffer,
    r.responseBuffer, s.rawVariables.var, and the upstream or
    downstream event type for s.on() instead.
  * Feature: added timeout argument for add(), set(), and incr() methods of a shared dictionary.
  * Bugfix: fixed checking for duplicate js_set variables.
  * Bugfix: fixed request Host header when the port is non-standard.
  * Bugfix: fixed handling of a zero-length request body in ngx.fetch() and r.subrequest().
  * Bugfix: fixed heap-buffer-overflow in Headers.get().
  * Bugfix: fixed r.subrequest() error handling.
  Core:
  * Feature: added zlib module for QuickJS engine.
  * Bugfix: fixed zlib.inflate().
  * Bugfix: fixed String.prototype.replaceAll() with a zero-length argument.
  * Bugfix: fixed retval handling after an exception in Array.prototype.toSpliced(),
    Array.prototype.toReversed(), Array.prototype.toSorted().
  * Bugfix: fixed RegExp.prototype[@@replace]() with replacements containing
    $', $` and strings with Unicode characters.
  * Bugfix: fixed a one-byte overread in decodeURI() and decodeURIComponent().
  * Bugfix: fixed tracking of argument scope.
  * Bugfix: fixed integer overflow in Date.parse().
  Changes with njs 0.8.4
  nginx modules:
  * Feature: the Server header for outgoing header can be set.
  * Improvement: validating URI and args arguments in r.subrequest().
  * Improvement: checking for duplicate js_set variables.
  * Bugfix: fixed clear() method of a shared dictionary without a timeout introduced in 0.8.3.
  * Bugfix: fixed r.send() method of a shared dictionary without a timeout with Buffer argument.
  Core:
  * Feature: added QuickJS engine support in CLI.
  * Bugfix: fixed atob() with non-padded base64 strings.
  Changes with njs 0.8.3
  nginx modules:
  * Bugfix: fixed Headers.set().
  * Bugfix: fixed js_set with Buffer values.
  * Bugfix: fixed clear() method of a shared dictionary when a timeout is not specified.
  * Bugfix: fixed stub_status statistics when js_periodic is enabled.
  Core:
  * Bugfix: fixed building with libxml2 2.12 and later.
  * Bugfix: fixed Date constructor for overflows and with NaN values.
  * Bugfix: fixed underflow in querystring.parse().
  * Bugfix: fixed potential buffer overread in String.prototype.match().
  * Bugfix: fixed parsing of for-in loops.
  * Bugfix: fixed parsing of hexadecimal, octal, and binary literals with no digits.
  Changes with njs 0.8.2
  nginx modules:
  * Feature: introduced console object. The following methods were introduced:
    error(), info(), log(), time(), timeEnd(), warn().
  * Bugfix: fixed HEAD response handling with large Content-Length in Fetch API.
  * Bugfix: fixed items() method for a shared dictionary.
  * Bugfix: fixed delete() method for a shared dictionary.
  Core:
  * Feature: extended fs module. Added fs.existsSync().
  * Bugfix: fixed xml module. Broken XML exception handling in xml.parse() method was fixed.
  * Bugfix: fixed Regexp.prototype.exec() with global regexp and Unicode input.
* Thu Oct 19 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.8.1:
  * Implement a number of useful language facilities around shared
    dictionaries, add more global nginx properties, and
    configuration directives (js_periodic, js_shared_dict_zone)
  * Possibly incompatible change: native methods are provided with
    retval argument. This change breaks compatibility with C
    extension for njs requiring the modification of the code.
  * A number of non-compliant deprecated String methods were
    removed
* Tue May  2 2023 Adam Majer <adam.majer@suse.de> 0.7.12
- update to 0.7.12
  nginx modules:
  * ) Bugfix: fixed Headers() constructor in Fetch API.
  Core:
  * ) Feature: added Hash.copy() method in "crypto" module.
  * ) Feature: added "zlib" module.
  * ) Improvement: added support for export {name as default}
    statement.
  * ) Bugfix: fixed Number constructor according to the spec.
  - Changes with njs 0.7.11
  nginx modules:
  * ) Bugfix: added missed linking with libxml2 for the dynamic module.
    The bug was introduced in 0.7.10.
  Core:
  * ) Feature: added XMLNode API to modify XML documents.
  * ) Change: removed XML_PARSE_DTDVALID during parsing of XML document
    due to security implications. The issue was introduced
    in 0.7.10. When XML_PARSE_DTDVALID is enabled, libxml2 parses and
    executes external entities present inside an XML document.
  * ) Bugfix: fixed the detection of await in arguments.
  * ) Bugfix: fixed Error() instance dumping when "name" prop is not
    primitive.
  * ) Bugfix: fixed array instance with a getter property dumping.
  * ) Bugfix: fixed njs_object_property() with NJS_WHITEOUT properties.
  * ) Bugfix: fixed func instance dumping with "name" as getter.
  * ) Bugfix: fixed attaching of a stack to an error object.
  * ) Bugfix: fixed String.prototype.replace() with replacement containing
    "$'", "$`".
* Thu Feb 23 2023 Adam Majer <adam.majer@suse.de> 0.7.10
- Initial package
